package com.asreader.asreaderdesktoplite.asreaderdesktoplitedemo;

import android.app.AlertDialog;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.asreader.asreaderdesktoplite.asreaderdesktoplitelib.AsReaderDesktopLiteLib;
import com.asreader.asreaderdesktoplite.asreaderdesktoplitelib.IAsReaderListener;

public class MainActivity extends AppCompatActivity implements IAsReaderListener {

    private PendingIntent mPermissionIntent;
    private IntentFilter filter;

    private UsbManager mUsbManager;
    private AsReaderDesktopLiteLib asReaderDesktopLiteLib;

    private TextView myTextView;

    private Button readBtn;
    private Button stopBtn;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mPermissionIntent = PendingIntent.getBroadcast(this, 0, new Intent("com.google.android.HID.action.USB_PERMISSION"), PendingIntent.FLAG_MUTABLE);
        this.filter = new IntentFilter("com.google.android.HID.action.USB_PERMISSION");
        this.filter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
        this.filter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        this.filter.addAction("ACTION_USB_SHOW_DEVICES_LIST");
        this.filter.addAction("ACTION_USB_DATA_TYPE");
        this.registerReceiver(this.mUsbReceiver, this.filter);


        asReaderDesktopLiteLib = new AsReaderDesktopLiteLib();
        asReaderDesktopLiteLib.setAsReaderListener(this);

        myTextView = (TextView)findViewById(R.id.myTextView);
        myTextView.setMovementMethod(ScrollingMovementMethod.getInstance());

    }

    private final BroadcastReceiver mUsbReceiver = new BroadcastReceiver() {
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if ("com.google.android.HID.action.USB_PERMISSION".equals(action)) {
                synchronized (this) {
                    UsbDevice device = intent.getParcelableExtra(UsbManager.EXTRA_DEVICE);
                    if (intent.getBooleanExtra(UsbManager.EXTRA_PERMISSION_GRANTED, false)) {
                        if (device != null) {
                            asReaderDesktopLiteLib.connect(device);
                        }
                    } else {

                    }
                }
            }
        }
    };


    @Override
    public void onDataReceived(final String tag) {

        ((MainActivity) this).runOnUiThread(new Runnable() {
            @Override
            public void run() {
                myTextView.append("\r\n"+tag);
                int offset=myTextView.getLineCount()*myTextView.getLineHeight();
                if(offset>(myTextView.getHeight()-myTextView.getLineHeight()-20)){
                    myTextView.scrollTo(0,offset-myTextView.getHeight()+myTextView.getLineHeight()+20);
                }
            }
        });
    }


    public void onClickConnect(View v) {
        myTextView.append("\r\nonClickConnect");
        mUsbManager = (UsbManager) getSystemService(Context.USB_SERVICE);
        asReaderDesktopLiteLib.initWithUsbManager(mUsbManager);
        if (mUsbManager.getDeviceList().size() > 0) {
            for (UsbDevice device : mUsbManager.getDeviceList().values()) {
                if (device.getVendorId() == asReaderDesktopLiteLib.VENDOR_ID && device.getProductId() == asReaderDesktopLiteLib.PRODUCT_ID) {
                    mUsbManager.requestPermission(device, mPermissionIntent);
                }
            }
        }
    }

    public void onClickRead(View v) {
        myTextView.append("\r\nonClickRead");
        asReaderDesktopLiteLib.read();
    }

    public void onClickStop(View v) {
        myTextView.append("\r\nonClickStop");
        asReaderDesktopLiteLib.stop();
    }

    public void onClickClear(View v) {
        myTextView.setText("");
    }

    public void onClickDisconnect(View v) {
        myTextView.append("\r\nonClickDisconnect");
        asReaderDesktopLiteLib.disconnect();
    }

}

